@@ -1,5 +1,6 @@
 from bs4 import BeautifulSoup
 from urllib.request import urlopen
+import requests
 
 class anime:
 
@@ -8,7 +9,14 @@ class anime:
         if " " in query:
             query = query.replace(" ", "%20")
 
-        html_page = urlopen(f"https://myanimelist.net/anime.php?q={query}")
+        to_open = f"https://myanimelist.net/anime.php?q={query}"
+
+        try:
+            html_page = urlopen(to_open)
+        except UnicodeEncodeError:
+            encoded_url = to_open.encode('ascii','ignore')
+            html_page = urlopen(str(encoded_url))
+        
         soup = BeautifulSoup(html_page, 'html.parser')
 
         anime_div = soup.find("td", {'class': 'borderClass bgColor0'})
@@ -35,4 +43,11 @@ class anime:
         ri = [i for i in recommendations if not i.isdigit()]  
         ri.pop(0)
 
-        return ri[:amount]
\ No newline at end of file
+        return ri[:amount]
+
+def waifu(category = "waifu"):
+    
+    url = requests.get(f"https://waifu.pics/api/sfw/{category}")
+    image = url.json()['url']
+
+    return image
\ No newline at end of file
